[Xorg-commit] xc/programs/Xserver/hw/darwin/quartz_1.3 Imakefile,1.1,1.1.4.1 rootlessAquaGlue.c,1.1,1.1.4.1 rootlessAquaImp.m,1.1,1.1.4.1

Kaleb Keithley xorg-commit at pdx.freedesktop.org
Thu Dec 18 21:29:45 EET 2003


Committed by: kaleb

Update of /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3
In directory pdx:/home/kaleb/xorg/xc.XORG-CURRENT/programs/Xserver/hw/darwin/quartz_1.3

Modified Files:
      Tag: XORG-CURRENT
	Imakefile rootlessAquaGlue.c rootlessAquaImp.m 
Log Message:
First pass at "Standard" Xinerama.
The sources for this came from Heather Lanigan's xinerama tree on 
Sourceforge.Net. 
No attempt has been made to handle previous, non-standard versions of 
the protocol. Nor has any attempt been made to preserve the ABI of 
previous versions -- that part will be added at a later time, and 
then probably only on systems that have nice object/linker semantics, 
e.g. ELF systems with weak symbols.



Index: Imakefile
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/Imakefile,v
retrieving revision 1.1
retrieving revision 1.1.4.1
diff -u -d -r1.1 -r1.1.4.1
--- Imakefile	14 Nov 2003 16:48:54 -0000	1.1
+++ Imakefile	18 Dec 2003 19:29:13 -0000	1.1.4.1
@@ -1,3 +1,4 @@
+XCOMM $XdotOrg$
 XCOMM $XFree86: xc/programs/Xserver/hw/darwin/quartz_1.3/Imakefile,v 1.1 2002/03/28 02:21:20 torrey Exp $
 
 #include <Server.tmpl>
@@ -20,8 +21,8 @@
 LinkSourceFile(quartzPasteboard.c,../quartz)
 LinkSourceFile(quartzPasteboard.h,../quartz)
 LinkSourceFile(quartzShared.h,../quartz)
-LinkSourceFile(pseudoramiX.c,../quartz)
-LinkSourceFile(pseudoramiX.h,../quartz)
+LinkSourceFile(pseudorama.c,../quartz)
+LinkSourceFile(pseudorama.h,../quartz)
 LinkSourceFile(quartzStartup.c,../quartz)
 LinkSourceFile(XDarwinStartup.c,../quartz)
 LinkSourceFile(XDarwinStartup.man,../quartz)
@@ -44,7 +45,7 @@
         rootlessScreen.c \
         rootlessValTree.c \
         rootlessWindow.c \
-        pseudoramiX.c
+        pseudorama.c
 
 OBJS =  Preferences.o \
         XApplication.o \
@@ -64,7 +65,7 @@
         rootlessScreen.o \
         rootlessValTree.o \
         rootlessWindow.o \
-        pseudoramiX.o
+        pseudorama.o
 
 INCLUDES = -I. -I$(SERVERSRC)/fb -I$(SERVERSRC)/mi -I$(SERVERSRC)/include \
            -I$(XINCLUDESRC) -I$(FONTINCSRC) -I$(SERVERSRC)/render \

Index: rootlessAquaGlue.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/rootlessAquaGlue.c,v
retrieving revision 1.1
retrieving revision 1.1.4.1
diff -u -d -r1.1 -r1.1.4.1
--- rootlessAquaGlue.c	14 Nov 2003 16:48:54 -0000	1.1
+++ rootlessAquaGlue.c	18 Dec 2003 19:29:13 -0000	1.1.4.1
@@ -1,3 +1,4 @@
+/* $XdotOrg$ */
 /*
  * Generic rootless to Aqua specific glue code
  *
@@ -208,7 +209,7 @@
 
     // This X11 screen covers all CoreGraphics displays we just found.
     // If there's more than one CG display, then video mirroring is on
-    // or PseudoramiX is on.
+    // or Pseudorama is on.
     displayInfo->displayCount = allocatedDisplays;
     displayInfo->displayIDs = displays;
 

Index: rootlessAquaImp.m
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/rootlessAquaImp.m,v
retrieving revision 1.1
retrieving revision 1.1.4.1
diff -u -d -r1.1 -r1.1.4.1
--- rootlessAquaImp.m	14 Nov 2003 16:48:54 -0000	1.1
+++ rootlessAquaImp.m	18 Dec 2003 19:29:13 -0000	1.1.4.1
@@ -1,3 +1,4 @@
+/* $XdotOrg$ */
 /*
  * Rootless implementation for Mac OS X Aqua environment
  */
@@ -7,7 +8,7 @@
 #include "XWindow.h"
 #include "fakeBoxRec.h"
 #include "quartzCommon.h"
-#include "pseudoramiX.h"
+#include "pseudorama.h"
 
 extern void ErrorF(const char *, ...);
 
@@ -19,18 +20,18 @@
 #define WINREC(rw) ((AquaWindowRec *)rw)
 
 
 // Multihead note: When rootless mode uses PseudoramiX, the
 // X server only sees one screen; only PseudoramiX itself knows
 // about all of the screens.
 
 int AquaDisplayCount()
 {
     aquaNumScreens = [[NSScreen screens] count];
 
-    if (noPseudoramiXExtension) {
+    if (noPseudoramaExtension) {
         return aquaNumScreens;
     } else {
-        return 1; // only PseudoramiX knows about the rest
+        return 1; // only Pseudorama knows about the rest
     }
 }
 
@@ -42,7 +43,7 @@
     *spp = 3;
     *bpp = 32;
 
-    if (noPseudoramiXExtension) {
+    if (noPseudoramaExtension) {
         NSScreen *screen = [[NSScreen screens] objectAtIndex:index];
         NSRect frame = [screen frame];
 
@@ -86,7 +87,7 @@
         *height = unionRect.size.height;
         *rowBytes = (*width) * (*bpp) / 8;
 
         // Tell PseudoramiX about the real screens.
         // InitOutput() will move the big screen to (0,0),
         // so compensate for that here.
         for (i = 0; i < [screens count]; i++) {
@@ -97,7 +98,7 @@
             // Skip this screen if it's a mirrored copy of an earlier screen.
             for (j = 0; j < i; j++) {
                 if (NSEqualRects(frame, [[screens objectAtIndex:j] frame])) {
-                    ErrorF("PseudoramiX screen %d is a mirror of screen %d.\n",
+                    ErrorF("Pseudorama screen %d is a mirror of screen %d.\n",
                            i, j);
                     break;
                 }
@@ -112,17 +113,17 @@
                 frame.size.height -= aquaMenuBarHeight;
             }
 
-            ErrorF("PseudoramiX screen %d added: %dx%d @ (%d,%d).\n", i,
+            ErrorF("Pseudorama screen %d added: %dx%d @ (%d,%d).\n", i,
                    (int)frame.size.width, (int)frame.size.height,
                    (int)frame.origin.x, (int)frame.origin.y);
 
             frame.origin.x -= unionRect.origin.x;
             frame.origin.y -= unionRect.origin.y;
 
-            ErrorF("PseudoramiX screen %d placed at X11 coordinate (%d,%d).\n",
+            ErrorF("Pseudorama screen %d placed at X11 coordinate (%d,%d).\n",
                    i, (int)frame.origin.x, (int)frame.origin.y);
 
-            PseudoramiXAddScreen(frame.origin.x, frame.origin.y,
+            PseudoramaAddScreen(frame.origin.x, frame.origin.y,
                                  frame.size.width, frame.size.height);
         }
     }
@@ -19,18 +20,18 @@
 
 
-// Multihead note: When rootless mode uses PseudoramiX, the
-// X server only sees one screen; only PseudoramiX itself knows
+// Multihead note: When rootless mode uses Pseudorama, the
+// X server only sees one screen; only Pseudorama itself knows
 // about all of the screens.
 
@@ -86,7 +87,7 @@
         *rowBytes = (*width) * (*bpp) / 8;
 
-        // Tell PseudoramiX about the real screens.
+        // Tell Pseudorama about the real screens.
         // InitOutput() will move the big screen to (0,0),
         // so compensate for that here.





More information about the xorg-commit mailing list